==> FancyBlockParticles-1.21.8-fabric-21.8.1.0-beta-sources.jar: hantonik/fbp/screen/FBPOculusWarningScreen.java <==
package hantonik.fbp.screen;

import hantonik.fbp.FancyBlockParticles;
import net.minecraft.ChatFormatting;
import net.minecraft.client.gui.GuiGraphics;
import net.minecraft.client.gui.components.*;
import net.minecraft.client.gui.layouts.GridLayout;
import net.minecraft.client.gui.layouts.HeaderAndFooterLayout;
import net.minecraft.client.gui.layouts.LayoutSettings;
import net.minecraft.client.gui.screens.Screen;
import net.minecraft.network.chat.ClickEvent;
import net.minecraft.network.chat.CommonComponents;
import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.Style;
import org.lwjgl.glfw.GLFW;

import java.net.URI;

public class FBPOculusWarningScreen extends Screen {
    private static final Component OCULUS_COMPONENT = Component.literal("Oculus").withStyle(ChatFormatting.AQUA);

    private final Screen lastScreen;

    private int exitCountdown = 20 * 5;

    private Button continueButton;
    private Button dontShowAgainButton;

    public FBPOculusWarningScreen(Screen lastScreen) {
        super(Component.translatable("screen.fbp.shaders_warning", OCULUS_COMPONENT));

        this.lastScreen = lastScreen;
    }

    @Override
    protected void init() {
        var layout = new HeaderAndFooterLayout(this, 52, 84);

        layout.addToHeader(new ImageButton(25, 25, FBPOptionsScreen.LOGO_SPRITES, button -> this.handleComponentClicked(Style.EMPTY.withClickEvent(new ClickEvent.OpenUrl(URI.create("https://www.curseforge.com/minecraft/mc-mods/fbp-renewed")))), CommonComponents.EMPTY), settings -> settings.alignHorizontallyLeft().alignVerticallyTop().padding(10)).setTooltip(Tooltip.create(Component.translatable("tooltip.fbp.common.homepage")));
        layout.addToHeader(new ImageButton(25, 25, FBPOptionsScreen.REPORT_SPRITES, button -> this.handleComponentClicked(Style.EMPTY.withClickEvent(new ClickEvent.OpenUrl(URI.create("https://github.com/Hantonik/FancyBlockParticles/issues")))), CommonComponents.EMPTY), settings -> settings.alignHorizontallyRight().alignVerticallyTop().padding(10)).setTooltip(Tooltip.create(Component.translatable("tooltip.fbp.common.report")));

        layout.addToHeader(new StringWidget(this.title, this.font), settings -> settings.alignHorizontallyCenter().alignVerticallyBottom());

        var contents = new GridLayout();
        contents.defaultCellSetting().alignHorizontallyCenter().paddingTop(5);

        var contentsHelper = contents.createRowHelper(1);
        contentsHelper.addChild(new MultiLineTextWidget(Component.translatable("gui.fbp.shaders_warning.message", OCULUS_COMPONENT), this.font).setMaxWidth(this.width - 45).setCentered(true), LayoutSettings.defaults().paddingTop(7));
        contentsHelper.addChild(new MultiLineTextWidget(Component.translatable("gui.fbp.shaders_warning.report", OCULUS_COMPONENT), this.font).setMaxWidth(this.width - 45).setCentered(true));

        layout.addToContents(contents);

        this.continueButton = Button.builder(CommonComponents.GUI_CONTINUE, button -> this.onClose()).build();
        this.continueButton.active = false;

        this.dontShowAgainButton = Button.builder(Component.translatable("button.fbp.shaders_warning.dont_show_again"), button -> {
            FancyBlockParticles.CONFIG.global.setDisableOculusWarning(true);
            FancyBlockParticles.CONFIG.save();

            this.onClose();
        }).build();

        this.dontShowAgainButton.active = false;

        var footer = new GridLayout();
        footer.defaultCellSetting().paddingHorizontal(5);

        var footerHelper = footer.createRowHelper(2);
        footerHelper.addChild(this.continueButton);
        footerHelper.addChild(this.dontShowAgainButton);

        layout.addToFooter(footer);

        layout.visitWidgets(this::addRenderableWidget);
        layout.arrangeElements();
    }

    @Override
    public void tick() {
        if (this.exitCountdown <= 0) {
            this.continueButton.active = true;
            this.dontShowAgainButton.active = true;
        } else
            this.exitCountdown--;
    }

    @Override
    public boolean shouldCloseOnEsc() {
        return this.exitCountdown <= 0;
    }

    @Override
    public boolean keyPressed(int keyCode, int scanCode, int modifiers) {
        if ((keyCode == GLFW.GLFW_KEY_ENTER || keyCode == GLFW.GLFW_KEY_SPACE) && modifiers == 0 && this.shouldCloseOnEsc()) {
            this.onClose();

            return true;
        }

        return super.keyPressed(keyCode, scanCode, modifiers);
    }

    @Override
    public void onClose() {
        this.minecraft.setScreen(this.lastScreen);
    }

    @Override
    public void render(GuiGraphics graphics, int mouseX, int mouseY, float partialTick) {
        super.render(graphics, mouseX, mouseY, partialTick);

        if (!this.continueButton.active)
            if (mouseX > this.continueButton.getX() && mouseX < this.continueButton.getX() + this.continueButton.getWidth() && mouseY > this.continueButton.getY() && mouseY < this.continueButton.getY() + this.continueButton.getHeight())
                graphics.setTooltipForNextFrame(this.font, Component.translatable("tooltip.fbp.shaders_warning.wait", String.valueOf((this.exitCountdown / 20) + 1)), mouseX, mouseY);

        if (!this.dontShowAgainButton.active)
            if (mouseX > this.dontShowAgainButton.getX() && mouseX < this.dontShowAgainButton.getX() + this.dontShowAgainButton.getWidth() && mouseY > this.dontShowAgainButton.getY() && mouseY < this.dontShowAgainButton.getY() + this.dontShowAgainButton.getHeight())
                graphics.setTooltipForNextFrame(this.font, Component.translatable("tooltip.fbp.shaders_warning.wait", String.valueOf((this.exitCountdown / 20) + 1)), mouseX, mouseY);
    }
}

==> FancyBlockParticles-1.21.10-fabric-21.10.0.0-beta-sources.jar: hantonik/fbp/screen/FBPOculusWarningScreen.java <==
package hantonik.fbp.screen;

import hantonik.fbp.FancyBlockParticles;
import net.minecraft.ChatFormatting;
import net.minecraft.client.gui.GuiGraphics;
import net.minecraft.client.gui.components.*;
import net.minecraft.client.gui.layouts.GridLayout;
import net.minecraft.client.gui.layouts.HeaderAndFooterLayout;
import net.minecraft.client.gui.layouts.LayoutSettings;
import net.minecraft.client.gui.screens.Screen;
import net.minecraft.client.input.KeyEvent;
import net.minecraft.network.chat.ClickEvent;
import net.minecraft.network.chat.CommonComponents;
import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.Style;
import org.lwjgl.glfw.GLFW;

import java.net.URI;

public class FBPOculusWarningScreen extends Screen {
    private static final Component OCULUS_COMPONENT = Component.literal("Oculus").withStyle(ChatFormatting.AQUA);

    private final Screen lastScreen;

    private int exitCountdown = 20 * 5;

    private Button continueButton;
    private Button dontShowAgainButton;

    public FBPOculusWarningScreen(Screen lastScreen) {
        super(Component.translatable("screen.fbp.shaders_warning", OCULUS_COMPONENT));

        this.lastScreen = lastScreen;
    }

    @Override
    protected void init() {
        var layout = new HeaderAndFooterLayout(this, 52, 84);

        layout.addToHeader(new ImageButton(25, 25, FBPOptionsScreen.LOGO_SPRITES, button -> this.handleComponentClicked(Style.EMPTY.withClickEvent(new ClickEvent.OpenUrl(URI.create("https://www.curseforge.com/minecraft/mc-mods/fbp-renewed")))), CommonComponents.EMPTY), settings -> settings.alignHorizontallyLeft().alignVerticallyTop().padding(10)).setTooltip(Tooltip.create(Component.translatable("tooltip.fbp.common.homepage")));
        layout.addToHeader(new ImageButton(25, 25, FBPOptionsScreen.REPORT_SPRITES, button -> this.handleComponentClicked(Style.EMPTY.withClickEvent(new ClickEvent.OpenUrl(URI.create("https://github.com/Hantonik/FancyBlockParticles/issues")))), CommonComponents.EMPTY), settings -> settings.alignHorizontallyRight().alignVerticallyTop().padding(10)).setTooltip(Tooltip.create(Component.translatable("tooltip.fbp.common.report")));

        layout.addToHeader(new StringWidget(this.title, this.font), settings -> settings.alignHorizontallyCenter().alignVerticallyBottom());

        var contents = new GridLayout();
        contents.defaultCellSetting().alignHorizontallyCenter().paddingTop(5);

        var contentsHelper = contents.createRowHelper(1);
        contentsHelper.addChild(new MultiLineTextWidget(Component.translatable("gui.fbp.shaders_warning.message", OCULUS_COMPONENT), this.font).setMaxWidth(this.width - 45).setCentered(true), LayoutSettings.defaults().paddingTop(7));
        contentsHelper.addChild(new MultiLineTextWidget(Component.translatable("gui.fbp.shaders_warning.report", OCULUS_COMPONENT), this.font).setMaxWidth(this.width - 45).setCentered(true));

        layout.addToContents(contents);

        this.continueButton = Button.builder(CommonComponents.GUI_CONTINUE, button -> this.onClose()).build();
        this.continueButton.active = false;

        this.dontShowAgainButton = Button.builder(Component.translatable("button.fbp.shaders_warning.dont_show_again"), button -> {
            FancyBlockParticles.CONFIG.global.setDisableOculusWarning(true);
            FancyBlockParticles.CONFIG.save();

            this.onClose();
        }).build();

        this.dontShowAgainButton.active = false;

        var footer = new GridLayout();
        footer.defaultCellSetting().paddingHorizontal(5);

        var footerHelper = footer.createRowHelper(2);
        footerHelper.addChild(this.continueButton);
        footerHelper.addChild(this.dontShowAgainButton);

        layout.addToFooter(footer);

        layout.visitWidgets(this::addRenderableWidget);
        layout.arrangeElements();
    }

    @Override
    public void tick() {
        if (this.exitCountdown <= 0) {
            this.continueButton.active = true;
            this.dontShowAgainButton.active = true;
        } else
            this.exitCountdown--;
    }

    @Override
    public boolean shouldCloseOnEsc() {
        return this.exitCountdown <= 0;
    }

    @Override
    public boolean keyPressed(KeyEvent event) {
        if ((event.input() == GLFW.GLFW_KEY_ENTER || event.input() == GLFW.GLFW_KEY_SPACE) && event.modifiers() == 0 && this.shouldCloseOnEsc()) {
            this.onClose();

            return true;
        }

        return super.keyPressed(event);
    }

    @Override
    public void onClose() {
        this.minecraft.setScreen(this.lastScreen);
    }

    @Override
    public void render(GuiGraphics graphics, int mouseX, int mouseY, float partialTick) {
        super.render(graphics, mouseX, mouseY, partialTick);

        if (!this.continueButton.active)
            if (mouseX > this.continueButton.getX() && mouseX < this.continueButton.getX() + this.continueButton.getWidth() && mouseY > this.continueButton.getY() && mouseY < this.continueButton.getY() + this.continueButton.getHeight())
                graphics.setTooltipForNextFrame(this.font, Component.translatable("tooltip.fbp.shaders_warning.wait", String.valueOf((this.exitCountdown / 20) + 1)), mouseX, mouseY);

        if (!this.dontShowAgainButton.active)
            if (mouseX > this.dontShowAgainButton.getX() && mouseX < this.dontShowAgainButton.getX() + this.dontShowAgainButton.getWidth() && mouseY > this.dontShowAgainButton.getY() && mouseY < this.dontShowAgainButton.getY() + this.dontShowAgainButton.getHeight())
                graphics.setTooltipForNextFrame(this.font, Component.translatable("tooltip.fbp.shaders_warning.wait", String.valueOf((this.exitCountdown / 20) + 1)), mouseX, mouseY);
    }
}
